SEAMM exec
==============================
[//]: # (Badges)
[![GitHub Actions Build Status](https://github.com/molssi-seamm/seamm_exec/workflows/CI/badge.svg)](https://github.com/molssi-seamm/seamm_exec/actions?query=workflow%3ACI)
[![codecov](https://codecov.io/gh/molssi-seamm/SEAMM exec/branch/main/graph/badge.svg)](https://codecov.io/gh/molssi-seamm/SEAMM exec/branch/main)


Classes to execute background codes for SEAMM

### Copyright

Copyright (c) 2023, Paul Saxe


#### Acknowledgements
 
Project based on the 
[Computational Molecular Science Python Cookiecutter](https://github.com/molssi/cookiecutter-cms) version 1.1.
